django-mongonaut — django-mongonaut 0.2.6 documentation

### Navigation

- index
- next |
- django-mongonaut 0.2.6 documentation »

# django-mongonaut

This is an introspective interface for Django and MongoDB. Built from scratch to replicate some of the Django admin functionality, but for MongoDB.

Contents:

- Installation
- Basic Usage
  - MongoAdmin: Fast and Easy
  - Advanced features of MongoAdmin
- Configuration
  - Basic Pattern
- Future Usage

# Features

(Implemented items are in bold)

- Introspection of Mongo data

  > - Introspection via mongo engine
  > - Introspection via pymongo (so you don’t need to define a schema ahead of time)
  > - Q based searches
  > - django.contrib.admin style browsing
  > - Automatic detection of field types
  > - Automatic discovery of collections
  > - Admin determination of which fields are displayed

- Data Management

  > - Editing on all fields except ListFields, EmbeddedFields, and ReferenceFields
  > - Automatic detection of widget types
  > - Text field shorthand for letting user quickly determine type when using without mongoengine
  > - Document Adds
  > - Document Deletes
  > - Admin authored Collection level document control functions

- Permissions

  > - User level controls
  > - Staff level controls
  > - Admin defined controls
  > - Group defined controls

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- django-mongonaut 0.2.6 documentation »